@@ -613,11 +613,11 @@ def email(file, testonly):
     "--format", type=click.Choice(["blackboard", "supermark"], case_sensitive=False)
 )
 @click.option(
-    "--teamsolution",
+    "--solution",
     help="Code of the team scratch card or team solution to shuffle the answer alternatives.",
-    required=False,
+    prompt="Solution",
 )
-def export(file, format, teamsolution):
+def export(file, format, solution):
     """
     Export the questions to another format.
     """
@@ -626,19 +626,13 @@ def export(file, format, teamsolution):
     questionaire = _load_rat_file(file_input)
     if questionaire is None:
         return
+    solution = Solution.create_solution_from_string(solution)
     if format == "blackboard":
-        text = questionaire.write_blackboard()
+        text = questionaire.write_blackboard(solution)
         export_file_path = os.path.join(os.path.dirname(file), "blackboard.txt")
         with open(export_file_path, "w", encoding="utf-8") as file:
             file.write(text)
     elif format == "supermark":
-        if teamsolution is None:
-            tell(
-                "You need to provide the solution for sorting, for instance using argument --teamsolution abcdabcd.",
-                "error",
-            )
-            return
-        solution = Solution.create_solution_from_string(teamsolution)
         text = questionaire.write_supermark(solution)
         export_file_path = os.path.join(os.path.dirname(file), "rat.md")
         with open(export_file_path, "w", encoding="utf-8") as file:
